@@ -14,7 +14,7 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #include <assert.h>
 #include <sys/types.h>
@@ -30,7 +30,7 @@
 #include <kapplication.h>
 #include <klocale.h>
 
-#include "KDat.h"
+#include "KDatMainWindow.h"
 #include "Options.h"
 #include "Tape.h"
 #include "TapeManager.h"
@@ -223,7 +223,7 @@ Tape* TapeDrive::readHeader()
     // Rewind tape.
     emit sigStatus( "Rewinding tape..." );
     if ( !rewind() ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Rewinding tape failed." ));
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Rewinding tape failed." ));
         return NULL;
     }
 
@@ -231,7 +231,7 @@ Tape* TapeDrive::readHeader()
     emit sigStatus( i18n( "Reading magic string..." ) );
     char magic[9];
     if ( read( magic, 9 ) < 9 ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Reading magic string failed." ));
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading magic string failed." ));
         return NULL;
     }
     if ( strncmp( "KDatMAGIC", magic, 9 ) ) {
@@ -243,24 +243,24 @@ Tape* TapeDrive::readHeader()
     emit sigStatus( i18n( "Reading version number..." ) );
     int version;
     if ( read( (char*)&version, 4 ) < 4 ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Reading version number failed." ));
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading version number failed." ));
         return NULL;
     }
 
     if ( version > KDAT_TAPE_HEADER_VERSION ) {
-        KMessageBox::information( KDat::getInstance(), i18n( "Tape was formatted by a more recent version of KDat. Consider upgrading." ));
+        KMessageBox::information( KDatMainWindow::getInstance(), i18n( "Tape was formatted by a more recent version of KDat. Consider upgrading." ));
     }
 
     // Read tape ID.
     emit sigStatus( i18n( "Reading tape ID..." ) );
     int len;
     if ( read( (char*)&len, 4 ) < 4 ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Reading tape ID length failed." ));
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading tape ID length failed." ));
         return NULL;
     }
     char* tapeID = new char[len];
     if ( read( tapeID, len ) < len ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Reading tape ID failed." ));
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading tape ID failed." ));
         delete [] tapeID;
         return NULL;
     }
