@@ -1,24 +1,48 @@
-//////////////////////////////////////////////////////////////
-// 	$Id: fbsdInterface.h,v 1.11 2002/06/07 11:44:59 coolo Exp $
-//
-// Author: Alex Hayward
-//
-//////////////////////////////////////////////////////////////
+/*
+** Copyright (C) 2000 by Alex Hayward
+**
+*/
+
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
 
 #ifndef FBSD_IFACE_H
 #define FBSD_IFACE_H
 
-#include "../config.h"
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 //#ifdef HAVE_FBSD_PKGTOOLS
 
 #include <qptrlist.h>
+#include <qmap.h>
 
 #include "packageInfo.h"
 #include "pkgInterface.h"
 
 class KDir;
 class cacheObj;
+class bsdPortsIndexItem;
 
 class fbsdInterface : public pkgInterface
 {
@@ -34,31 +58,42 @@ public:
 
   packageInfo *getPackageInfo(char mode, const QString &name, const QString &version);
   QStringList getFileList(packageInfo *p);
+  QStringList getChangeLog(packageInfo *p);
+
+  bool filesTab(packageInfo *p);
+  // If files tab is to be enabled
+
+  bool changeTab(packageInfo *p);
+  // If change log tab is to be enabled
 
   QString uninstall(int uninstallFlags, QPtrList<packageInfo> *p, bool &test);
   QString uninstall(int uninstallFlags, packageInfo *p, bool &test);
-  QString doUninstall(int uninstallFlags, QString packs, bool &test);
-  QString doInstall(int installFlags, QString packs, bool &test);
+  QString doUninstall(int uninstallFlags, const QString &packs, bool &test);
+  QString doInstall(int installFlags, const QString &packs, bool &test);
 
-  QStringList FindFile(const QString &name);
+  QStringList FindFile(const QString &name, bool seachAll=false);
   void collectDepends(packageInfo *p, const QString &name, int src);
   bool parseName(const QString& name, QString *n, QString *v);
 
   void listInstalledPackages(QPtrList<packageInfo> *pki);
   void listPackages(QPtrList<packageInfo> *pki);
 
+  QDict <bsdPortsIndexItem> ports;
 public slots:
   void setLocation();
   void setAvail(LcacheObj *);
 
 private:
   /**
-   * @short Add the name and version identifiers to a QDict<QString>.
+   * @short Add the name and version identifiers to a QMap<QString, QString>.
    *
    * name is parsed in to name and version and these are added to
    * d. Errors are handled.
    */
-  void addNV(QDict<QString> *d, const QString &name);
+  void addNV(QMap<QString, QString> &d, const QString &name);
+  int parseItem(QStringList::Iterator &it, QString &name, QString &value, QString separator, QStringList list );
+  int pathInfo(QMap<QString, QString> &a);
+
 };
 
 /**
@@ -82,7 +117,7 @@ public:
    *
    * dname is the name of the base directory of this ports/packages tree.
    */
-  bsdPortsIndexItem(char *desc, bool binaries, QString dname);
+  bsdPortsIndexItem(fbsdInterface *parent, char *desc, bool binaries, const QString &dname);
 
   /** @short true if this has a binary packages. */
   bool bin;
@@ -96,36 +131,21 @@ public:
   /** @short The next item in this linked list */
   bsdPortsIndexItem *next;
 
-  const char *name;
-  const char *path;
-  const char *prefix;
-  const char *comment;
-  const char *desc_path;
-  const char *maint;
-  const char *cats;
-  const char *bdeps;
-  const char *rdeps;
+  QStringList fields;
+
+  enum {NAME=0, PATH, PREFIX, COMMENT, DESC_PATH, MAINT, CATS, BDEPS, RDEPS};
+
   QString bin_filename;
   QString bin_filename_base;
   QString port_dirname;
 
-  /**
-   * @short Find a port from the ports index (by name).
-   */
-  static bsdPortsIndexItem *find(const QString &name);
-
-  /**
-   * @short A hash table based on the value returned by calc_hash1 or hash1;
-   */
-  static bsdPortsIndexItem *lists[256];
-
-  /**
+   /**
    * @short Given the path to an INDEX file process each port in it.
    *
    * binaries should be true if the file is an index for packages, false for ports.
    * dname is the base directory.
    */
-  static void processFile(const QString &fname, bool binaries, const QString &dname);
+  static void processFile(fbsdInterface *parent, const QString &fname, bool binaries, const QString &dname);
 
 private:
   unsigned int name_hash;
@@ -136,5 +156,3 @@ private:
 
 #endif
 
-
-
