@@ -294,9 +294,10 @@ void KPKG::readProperties(KConfig *config)
     prop_restart = true;
 }
 
-void KPKG::closeEvent ( QCloseEvent *) {
-    kpackage->fileQuit();
-}
+bool KPKG::queryClose() {
+    kpackage->cleanUp();
+    return true;
+} 
 
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
@@ -397,6 +398,13 @@ void KPACKAGE::setup()
 }
 
 void KPACKAGE::fileQuit()		// file->quit selected from menu
+{
+  cleanUp();
+
+  KApplication::exit(0);	// exit the application
+}
+
+void KPACKAGE::cleanUp()		// file->quit selected from menu
 {
   kpkg->writeSettings();
   if (opts->DCache >= Opts::SESSION) {
@@ -405,8 +413,6 @@ void KPACKAGE::fileQuit()		// file->quit selected from menu
   if (opts->PCache >= Opts::SESSION) {
     cacheObj::clearPCache(); // clear package caches if needed
   }
-
-  KApplication::exit(0);	// exit the application
 }
 
 void KPACKAGE::reload()
