@@ -12,15 +12,15 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  **/
  
 #ifndef _SID_H_
 #define _SID_H_
 
 #include <qstring.h>
- 
+
 class SID {
     
 public:
@@ -40,10 +40,15 @@ public:
   uint getRID() const ;
   const QString &getDOM() const;
 
+  static uint uid2rid( uint uid );
+  static uint gid2rid( uint gid );
+  static void setAlgRidBase( uint base ) { mAlgRidBase = base; };
+  static uint getAlgRidBase() { return mAlgRidBase; };
 private:
   void updateSID();
   QString mSid, mDom;
   uint mRid;
+  static uint mAlgRidBase;
 };
 
 #endif //_SID_H_
