@@ -1,3 +1,30 @@
+/* standalone.cpp
+**
+** Copyright (C) 2000,2001 by Bernhard Rosenkraenzer
+**
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
+
 #include <qapplication.h>
 #include <qobject.h>
 #include <qwhatsthis.h>
@@ -11,9 +38,9 @@ Standalone::Standalone(QWidget *parent, const char *name):QWidget(parent,name)
 	m=new MainWidget(this);
 	connect(m, SIGNAL(configChanged()), SLOT(configChanged()));
 	actions=new QHButtonGroup(this);
-	_whatsthis=new QPushButton(_("&What's this?"), actions);
+	_whatsthis=new QPushButton(_("&What's This?"), actions);
 	_whatsthis->setAccel(SHIFT+Key_F1);
-	QWhatsThis::add(_whatsthis, _("The <i>What's This?</i> button is part of this program's help system. Click on the What's This button, then on any widget in the window to get information (like this) on it."));
+	QWhatsThis::add(_whatsthis, _("The <i>What's This?</i> button is part of this program's help system. Click on the What's This? button then on any widget in the window to get information (like this) on it."));
 	connect(_whatsthis, SIGNAL(clicked()), SLOT(whatsthis()));
 	_help=new QPushButton(_("&Help"), actions);
 	_help->setAccel(Key_F1);
